@@ -95,15 +95,11 @@ gtk_plot_bar_get_type (void)
 static void
 gtk_plot_bar_class_init (GtkPlotBarClass *klass)
 {
-  GtkObjectClass *object_class;
-  GtkWidgetClass *widget_class;
   GtkPlotDataClass *data_class;
   GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
 
   parent_class = g_type_class_ref (gtk_plot_data_get_type ());
 
-  object_class = (GtkObjectClass *) klass;
-  widget_class = (GtkWidgetClass *) klass;
   data_class = (GtkPlotDataClass *) klass;
 
   gobject_class->set_property = gtk_plot_bar_set_property;
@@ -179,13 +175,10 @@ gtk_plot_bar_get_property (GObject      *object,
 static void
 gtk_plot_bar_init (GtkPlotBar *dataset)
 {
-  GtkWidget *widget;
   GdkColor black, white;
   GdkColormap *colormap;
   GtkPlotArray *dim;
 
-  widget = GTK_WIDGET(dataset);
-
   colormap = gdk_colormap_get_system();
 
   gdk_color_black(colormap, &black);
@@ -343,7 +336,6 @@ gtk_plot_bar_draw_symbol(GtkPlotData *dataset,
 static void
 gtk_plot_bar_draw_legend(GtkPlotData *data, gint x, gint y)
 {
-  GtkPlotBar *bar;
   GtkPlot *plot = NULL;
   GtkPlotText legend;
   GdkRectangle area;
@@ -351,8 +343,6 @@ gtk_plot_bar_draw_legend(GtkPlotData *data, gint x, gint y)
   gdouble m;
   GtkAllocation allocation;
 
-  bar = GTK_PLOT_BAR(data);
-
   g_return_if_fail(data->plot != NULL);
   g_return_if_fail(GTK_IS_PLOT(data->plot));
   g_return_if_fail(gtk_widget_get_visible(GTK_WIDGET(data)));
