@@ -1,5 +1,6 @@
 char *fake = N_("Compose two functions");
 char *fake = N_("Compose a function with itself n times, passing x as argument, and returning x if n == 0");
+char *fake = N_("Print a table of values for f(n) for numbers from from vector v, or if v is a number for integers from 1 to v");
 char *fake = N_("Make a string");
 char *fake = N_("Tolerance of the Chop function");
 char *fake = N_("How many iterations to try to find the limit for continuity and limits");
@@ -128,6 +129,7 @@ char *fake = N_("Is a matrix skew-Hermitian");
 char *fake = N_("Is a matrix unitary");
 char *fake = N_("Get the Jordan block corresponding to lambda and n");
 char *fake = N_("Get the kernel (nullspace) of a linear transform");
+char *fake = N_("Compute the Kronecker product of two matrices");
 char *fake = N_("Get the LU decomposition of A and store the result in the L and U which should be references.  If not possible returns false.");
 char *fake = N_("Get the i-j minor of a matrix");
 char *fake = N_("Return the columns that are not the pivot columns of a matrix");
@@ -215,6 +217,8 @@ char *fake = N_("Returns 1 if and only if all elements are zero");
 char *fake = N_("The error function, 2/sqrt(pi) * int_0^x e^(-t^2) dt");
 char *fake = N_("Fejer kernel of order n");
 char *fake = N_("Returns 1 if and only if all elements are equal");
+char *fake = N_("Principal branch of the Lambert W function for real values greater than or equal to -1/e");
+char *fake = N_("The minus-one branch of the Lambert W function for real values between -1/e and 0");
 char *fake = N_("Find the first value where f(x)=0");
 char *fake = N_("Moebius mapping of the disk to itself mapping a to 0");
 char *fake = N_("Moebius mapping using the cross ratio taking z2,z3,z4 to 1,0, and infinity respectively");
@@ -230,10 +234,12 @@ char *fake = N_("Convert radians to degrees");
 char *fake = N_("Find roots of a cubic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
-char *fake = N_("Find root of a function using the bisection method");
-char *fake = N_("Find root of a function using the method of false position");
+char *fake = N_("Find root of a function using the bisection method to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
+char *fake = N_("Find root of a function using the method of false position to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
 char *fake = N_("Find root of a function using the Muller's method");
-char *fake = N_("Find root of a function using the secant method");
+char *fake = N_("Find root of a function using the secant method to within TOL tolerance in up to N iterations.  f(a) and f(b) must have opposite signs.");
+char *fake = N_("Attempt to find a zero of a functionf with derivative df and second derivative ddf using Halleys's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
+char *fake = N_("Attempt to find a zero of a functionf with derivative df using Newton's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
 char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
 char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
@@ -248,7 +254,7 @@ char *fake = N_("Calculate median of each row in a matrix");
 char *fake = N_("Calculate the population standard deviations of rows of a matrix and return a vertical vector");
 char *fake = N_("Calculate the standard deviations of rows of a matrix and return a vertical vector");
 char *fake = N_("Calculate the standard deviation of a whole matrix");
-char *fake = N_("Run newton's method on a polynomial to attempt to find a root, returns after two successive values are within epsilon or after maxn tries (then returns null)");
+char *fake = N_("Attempt to find a root of a polynomial using Newton's method, returning after two successive values are within epsilon or after maxn tries (then returns null)");
 char *fake = N_("Returns a set where every element of X appears only once");
 char *fake = N_("Returns a set theoretic union of X and Y (X and Y are vectors pretending to be sets)");
 char *fake = N_("For a Hilbert function that is c for degree d, given the Macaulay bound for the Hilbert function of degree d+1 (The c^<d> operator from Green's proof)");
