@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2012 Jiri (George) Lebl
+ * Copyright (C) 1997-2014 Jiri (George) Lebl
  *
  * Author: Jiri (George) Lebl
  *
@@ -105,6 +105,8 @@ gboolean gel_interrupted = FALSE;
 static GSList *curfile = NULL;
 static GSList *curline = NULL;
 
+static GHashTable *gel_bodyhash = NULL;
+
 /*from lexer.l*/
 int my_yyinput(void);
 
@@ -1375,6 +1377,37 @@ append_func (GelOutput *gelo, GelEFunc *f)
 	}
 }
 
+void
+gel_print_func (GelOutput *gelo,
+		GelEFunc *f)
+{
+	if G_UNLIKELY (f == NULL) {
+		gel_errorout (_("NULL function!"));
+		gel_output_string (gelo, "(?)");
+		return;
+	}
+
+	if (f->type == GEL_VARIABLE_FUNC) {
+		gel_print_etree (gelo, f->data.user, FALSE);
+	} else {
+		gel_output_push_nonotify (gelo);
+
+		/* all non-value nodes printed as <ci></ci> and
+		 * value nodes as <cn></cn> */
+		if (gel_calcstate.output_style == GEL_OUTPUT_MATHML)
+			gel_output_string (gelo, "<ci>");
+
+		append_func (gelo, f);
+
+		/* all non-value nodes printed as <ci></ci> and
+		 * value nodes as <cn></cn> */
+		if (gel_calcstate.output_style == GEL_OUTPUT_MATHML)
+			gel_output_string (gelo, "</ci>");
+
+		gel_output_pop_nonotify (gelo);
+	}
+}
+
 /*make a string representation of an expression*/
 void
 gel_print_etree (GelOutput *gelo,
@@ -1845,9 +1878,24 @@ compile_funcs_in_dict (FILE *outfile, GSList *dict, gboolean is_extra_dict)
 			body = g_strdup (func->id->uncompiled);
 			g_assert (body != NULL);
 		}
+		if ( ! is_extra_dict) {
+			GelToken *at;
+			if (NULL != (at = g_hash_table_lookup (gel_bodyhash, body))) {
+				g_free (body);
+				body = g_strdup_printf ("t;%s", at->token);
+			/* only do this if it makes sense */
+			} else if (strlen (body) > strlen(func->id->token) + 2) {
+
+				g_hash_table_insert (gel_bodyhash,
+						     g_strdup(body),
+						     func->id);
+			}
+		}
+
 		if (func->type == GEL_USER_FUNC) {
 			fprintf (outfile,
-				 "%c;%d;%s;%s;n%d;v%d;p%d;o%d;l%d;e%d;b%d",
+				 /*old "%c;%d;%s;%s;n%d;v%d;p%d;o%d;l%d;e%d;b%d",*/
+				 "%c;%d;%s;%s;%d;%d;%d;%d;%d;%d;%d",
 				 fs,
 				 (int)strlen (body),
 				 func->id->token,
@@ -1907,34 +1955,31 @@ compile_funcs_in_dict (FILE *outfile, GSList *dict, gboolean is_extra_dict)
 
 		help = gel_get_help (func->id->token, FALSE /* insert */);
 		if (help != NULL && help->aliasfor != NULL) {
-			fprintf (outfile, "A;%s;%s\n",
-				 help->aliasfor,
-				 func->id->token);
+			fprintf (outfile, "A;%s\n",
+				 help->aliasfor);
 		} else if (help != NULL) {
 			if (help->category != NULL)
-				fprintf (outfile, "C;%s;%s\n",
-					 func->id->token,
+				fprintf (outfile, "C;%s\n",
 					 help->category);
-			if (help->description != NULL)
-				fprintf (outfile, "D;%s;%s\n",
-					 func->id->token,
-					 help->description);
+			if (help->description != NULL) {
+				char *s = gel_encode_string (help->description);
+				fprintf (outfile, "D;%s\n", s);
+				g_free (s);
+			}
 			if (help->help_link != NULL) {
 				char *s = gel_encode_string (help->help_link);
-				fprintf (outfile, "L;%s;%s\n",
-					 func->id->token, s);
+				fprintf (outfile, "L;%s\n", s);
 				g_free (s);
 			}
 			/* FIXME: This may be too demanding */
 			if (help->help_html != NULL) {
 				char *s = gel_encode_string (help->help_html);
-				fprintf (outfile, "H;%s;%s\n",
-					 func->id->token, s);
+				fprintf (outfile, "H;%s\n", s);
 				g_free (s);
 			}
 		}
 		if (func->id->protected_)
-			fprintf (outfile,"P;%s\n",func->id->token);
+			fprintf (outfile,"P\n");
 	}
 }
 
@@ -1947,8 +1992,13 @@ gel_compile_all_user_funcs (FILE *outfile)
 	if (funcs == NULL)
 		return;
 	funcs = g_slist_reverse (g_slist_copy (funcs));
+	gel_bodyhash = g_hash_table_new_full (g_str_hash,
+					      g_str_equal,
+					      g_free, NULL);
 	compile_funcs_in_dict (outfile, funcs, FALSE /* is_extra_dict */);
 	g_slist_free (funcs);
+	g_hash_table_destroy (gel_bodyhash);
+	gel_bodyhash = NULL;
 }
 
 /* FIXME: function reading is almost identical to that for FUNCTION_NODEs
@@ -1960,6 +2010,8 @@ load_compiled_fp (const char *file, FILE *fp)
 	int buf_size = 4096;
 	gboolean break_on_next = FALSE;
 	GelEFunc *last_func = NULL;
+	char *cur_id = NULL;
+	GelToken *cur_tok = NULL;
 
 	buf = g_new (char, buf_size);
 
@@ -2027,51 +2079,36 @@ load_compiled_fp (const char *file, FILE *fp)
 			continue;
 		} else if (*p == 'A') {
 			char *d;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
 				continue;
 			}
+
 			d = strtok_r (NULL,";", &ptrptr);
 			if G_UNLIKELY (!d) {
 				gel_errorout (_("Badly formed record"));
 				continue;
 			}
-			gel_add_alias(p,d);
+			gel_add_alias (d, cur_id);
 			continue;
 		} else if (*p == 'C') {
 			char *d;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
 				continue;
 			}
+
 			d = strtok_r (NULL,";", &ptrptr);
 			if G_UNLIKELY (!d) {
 				gel_errorout (_("Badly formed record"));
 				continue;
 			}
-			gel_add_category(p,d);
+			gel_add_category (cur_id, d);
 			continue;
 		} else if (*p == 'D') {
-			char *d;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
-				continue;
-			}
-			d = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!d) {
-				gel_errorout (_("Badly formed record"));
-				continue;
-			}
-			gel_add_description(p,d);
-			continue;
-		} else if (*p == 'L') {
 			char *d, *h;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
 				continue;
 			}
 			d = strtok_r (NULL,";", &ptrptr);
@@ -2080,14 +2117,29 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			h = gel_decode_string (d);
-			gel_add_help_link (p, h);
+			gel_add_description (cur_id, h);
+			g_free (h);
+			continue;
+		} else if (*p == 'L') {
+			char *d, *h;
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
+				continue;
+			}
+
+			d = strtok_r (NULL,";", &ptrptr);
+			if G_UNLIKELY (!d) {
+				gel_errorout (_("Badly formed record"));
+				continue;
+			}
+			h = gel_decode_string (d);
+			gel_add_help_link (cur_id, h);
 			g_free (h);
 			continue;
 		} else if (*p == 'H') {
 			char *d, *h;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
 				continue;
 			}
 			d = strtok_r (NULL,";", &ptrptr);
@@ -2096,18 +2148,15 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			h = gel_decode_string (d);
-			gel_add_help_html (p, h);
+			gel_add_help_html (cur_id, h);
 			g_free (h);
 			continue;
 		} else if (*p == 'P') {
-			GelToken *tok;
-			p = strtok_r (NULL,";", &ptrptr);
-			if G_UNLIKELY (!p) {
-				gel_errorout (_("Badly formed record"));
+			if G_UNLIKELY (cur_id == NULL) {
+				gel_errorout (_("Record out of place"));
 				continue;
 			}
-			tok = d_intern(p);
-			tok->protected_ = 1;
+			cur_tok->protected_ = 1;
 			continue;
 		} else if G_UNLIKELY (*p != 'F' && *p != 'V' && *p != 'f' && *p != 'v') {
 			gel_errorout (_("Badly formed record"));
@@ -2140,6 +2189,11 @@ load_compiled_fp (const char *file, FILE *fp)
 			continue;
 		}
 		tok = d_intern(p);
+		if ( ! extra_dict) {
+			g_free (cur_id);
+			cur_id = g_strdup (p);
+			cur_tok = tok;
+		}
 
 		if (type == GEL_USER_FUNC) {
 			/*symbolic_id*/
@@ -2160,7 +2214,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			nargs = -1;
-			sscanf(p,"n%d",&nargs);
+			/*old sscanf(p,"n%d",&nargs); */
+			sscanf(p,"%d",&nargs);
 			if G_UNLIKELY (nargs == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2173,7 +2228,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			vararg = -1;
-			sscanf(p,"v%d",&vararg);
+			/*old sscanf(p,"v%d",&vararg); */
+			sscanf(p,"%d",&vararg);
 			if G_UNLIKELY (vararg == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2186,7 +2242,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			propagate_mod = -1;
-			sscanf(p,"p%d",&propagate_mod);
+			/*old sscanf(p,"p%d",&propagate_mod); */
+			sscanf(p,"%d",&propagate_mod);
 			if G_UNLIKELY (propagate_mod == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2199,7 +2256,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			no_mod_all_args = -1;
-			sscanf(p,"o%d",&no_mod_all_args);
+			/*old sscanf(p,"o%d",&no_mod_all_args); */
+			sscanf(p,"%d",&no_mod_all_args);
 			if G_UNLIKELY (no_mod_all_args == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2212,7 +2270,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			local_all = -1;
-			sscanf(p,"l%d",&local_all);
+			/*old sscanf(p,"l%d",&local_all); */
+			sscanf(p,"%d",&local_all);
 			if G_UNLIKELY (local_all == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2225,7 +2284,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			never_on_subst_list = -1;
-			sscanf(p,"e%d",&never_on_subst_list);
+			/*old sscanf(p,"e%d",&never_on_subst_list); */
+			sscanf(p,"%d",&never_on_subst_list);
 			if G_UNLIKELY (never_on_subst_list == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2238,7 +2298,8 @@ load_compiled_fp (const char *file, FILE *fp)
 				continue;
 			}
 			built_subst_dict = -1;
-			sscanf(p,"b%d",&built_subst_dict);
+			/*old sscanf(p,"b%d",&built_subst_dict); */
+			sscanf(p,"%d",&built_subst_dict);
 			if G_UNLIKELY (built_subst_dict == -1) {
 				gel_errorout (_("Badly formed record"));
 				continue;
@@ -2313,10 +2374,26 @@ load_compiled_fp (const char *file, FILE *fp)
 		p=strchr(b2,'\n');
 		if(p) *p='\0';
 
+		if (b2[0] == 't') {
+			GelToken *at = d_intern (&(b2[2]));
+			if (at->uncompiled == NULL) {
+				gel_errorout (_("Missing value for function"));
+				g_slist_free(li);
+				goto continue_reading;
+			}
+			b2 = g_strdup (at->uncompiled);
+		}
+
 		if (extra_dict) {
 			GelEFunc *func;
+			GelETree *t = gel_decompile_tree (b2);
+			if (t == NULL) {
+				gel_errorout (_("Missing value for function"));
+				g_slist_free(li);
+				goto continue_reading;
+			}
 			if (type == GEL_USER_FUNC) {
-				func = d_makeufunc (tok, NULL, li, nargs, NULL);
+				func = d_makeufunc (tok, t, li, nargs, NULL);
 				func->vararg = vararg ? 1 : 0;
 				func->symbolic_id = symbolic_tok;
 				func->propagate_mod = propagate_mod ? 1 : 0;
@@ -2327,7 +2404,7 @@ load_compiled_fp (const char *file, FILE *fp)
 				func->subst_dict = subst_dict;
 				func->local_idents = local_idents;
 			} else /*GEL_VARIABLE_FUNC*/ {
-				func = d_makevfunc (tok, NULL);
+				func = d_makevfunc (tok, t);
 			}
 			func->context = -1;
 			if G_UNLIKELY (last_func == NULL)
@@ -2364,6 +2441,7 @@ continue_reading:
 	}
 	fclose(fp);
 	g_free (buf);
+	g_free (cur_id);
 }
 
 void
